@@ -1,51 +1,53 @@
 package Text::Trac;
 
 use strict;
+use warnings;
 
 use Text::Trac::Context;
 use Text::Trac::BlockNode;
 
-our $VERSION = '0.15';
+our $VERSION = '0.17';
 
 my %Defaults = (
-    html              => '',
-    permalink         => '',
-    min_heading_level => 1,
+	html              => '',
+	permalink         => '',
+	min_heading_level => 1,
+	class             => 1,
 );
 
 sub new {
-    my ( $class, %args ) = @_;
+	my ( $class, %args ) = @_;
 
-    my $self = {
-        %Defaults,
-        %args,
-    };
+	my $self = { %Defaults, %args, };
 
-    bless $self, $class;
+	bless $self, $class;
 }
 
 sub parse {
-    my $self = shift;
-    my $text = shift or return;
+	my $self = shift;
+	my $text = shift or return;
 
-    $self->{trac_url} = '/' unless defined $self->{trac_url};
-    for ( keys %$self ) {
-        if ( $_ =~ /^trac.+url$/ ) {
-            $self->{$_} .= '/' if $self->{$_} !~ m!/$!;
-        }
-    }
+	$self->{trac_url} = '/' unless defined $self->{trac_url};
+	for ( keys %$self ) {
+		if ( $_ =~ /^trac.+url$/ ) {
+			$self->{$_} .= '/' if $self->{$_} !~ m!/$!;
+		}
+	}
 
-    my $c = Text::Trac::Context->new({
-        %$self,
-        text => $text,
-    });
+	my $c = Text::Trac::Context->new(
+		{
+			%$self, text => $text,
+		}
+	);
 
-    my $node = Text::Trac::BlockNode->new({
-        context  => $c,
-    });
-    $node->parse;
+	my $node = Text::Trac::BlockNode->new(
+		{
+			context => $c,
+		}
+	);
+	$node->parse;
 
-    $self->{html} = $c->html;
+	$self->{html} = $c->html;
 }
 
 sub html { $_[0]->{html}; }
@@ -59,10 +61,6 @@ __END__
 
 Text::Trac - Perl extension for formatting text with Trac Wiki Style.
 
-=head1 VERSION
-
-Version 0.12
-
 =head1 SYNOPSIS
 
     use Text::Trac;
